<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Jonathan Daniel <jdaniel@interworx.com>
 * @date    Mar 11, 2010
 */

/**
 * Tests that the update cron is parsing the yum output properly.
 *
 * @package    InterWorx
 * @subpackage Tests
 * @group      slow-tests
 */
class CLI_UpdateCronTest extends PHPUnit_Framework_TestCase {

  private $_rpms = array( 'cos4x-i386'   => 'http://updates.interworx.com/centos/4/updates/i386/RPMS/tzdata-2011d-3.el4.noarch.rpm',
                          'cos5x-i386'   => 'http://updates.interworx.com/distros/centos/5/updates/i386/RPMS/tzdata-2012j-2.el5.i386.rpm',
                          'cos6x-i386'   => 'http://updates.interworx.com/distros/centos/6/updates/i386/Packages/tzdata-2014h-1.el6.noarch.rpm',
                          'cos4x-x86_64' => 'http://updates.interworx.com/centos/4/updates/x86_64/RPMS/tzdata-2011d-3.el4.noarch.rpm',
                          'cos5x-x86_64' => 'http://updates.interworx.com/distros/centos/5/updates/x86_64/RPMS/tzdata-2012j-2.el5.x86_64.rpm',
                          'cos6x-x86_64' => 'http://updates.interworx.com/distros/centos/6/updates/x86_64/Packages/tzdata-2014h-1.el6.noarch.rpm',
                          'cos7x-x86_64' => 'http://updates.interworx.com/distros/centos/7/updates/x86_64/Packages/tzdata-2014h-1.el7.noarch.rpm' );

  /**
   * Install some old and outdated RPMs so we can let yum do it's thing.
   */
  public function testSetupDowngradeTzdataPackage() {
    $sysinfo = new IWorxSysInfo();

    $distro = $sysinfo->distro();

    $short_dist = false;

    $arch = trim( `uname -i` );
    if( strstr( $distro, 'CentOS release 5' ) ) {
      $short_dist = "cos5x-{$arch}";
    } else if( strstr( $distro, 'CentOS release 4' ) ) {
      $short_dist = "cos4x-{$arch}";
    } else if( strstr( $distro, 'CentOS release 6' ) ) {
      $short_dist = "cos6x-{$arch}";
    } else if( strstr( $distro, 'CentOS Linux release 7' ) ) {
      $short_dist = "cos7x-{$arch}";
    }

    $this->assertNotEquals( false, $short_dist, 'Unable to determine distro' );

    $Cmd = new Command( 'rpm -Uvh --force ' . $this->_rpms[ $short_dist ] );
    $Cmd->exec();

    if( $Cmd->wasSuccessful() === false ) {
      foreach( $Cmd->getOutput() as $line ) {
        IWorxConsole::echoLine( $line );
      }
    }

    $this->assertTrue( $Cmd->wasSuccessful(),
                       'Downgrading the tzdata package failed. This probably ' .
                       'means someone needs to update the UpdateCronTest again ' .
                       'to point to a newer package.' );
  }

  /**
   * Test that the records were properly created.
   *
   * This should help let us know when something breaks from yum changing their
   * output.
   *
   * @depends testSetupDowngradeTzdataPackage
   */
  public function testUpdateRecordCreated() {
    $update = Ini::get( Ini::IWORX_CRON, 'update' );
    $cmd    = "{$update} --check-for-updates";

    IWorxExec::exec( $cmd, $result, $retval );

    $cmd = "{$update} --os --apply";

    IWorxExec::exec( $cmd, $result, $retval );

    $ok = $this->_updateExistsFromCurrentBatch( 'tzdata' );

    $msg = 'Updates are missing! Did yum change their output again?';

    $this->assertTrue( $ok, $msg );
  }

  /**
   * Given a package name, check to see if it exists in the current batch.
   *
   * @param string $name
   * @return boolean
   *
   * @depends testSetupBeforeClass
   */
  private function _updateExistsFromCurrentBatch( $name ) {
    $Payload = Payload_Factory_NW_Updates::recentHistory();
    $data    = $Payload->getData();
    return $data[0]->name === $name;
  }
}
