<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Jonathan Daniel <jdaniel@interworx.com>
 * @date    Apr 26, 2010
 */

/**
 * Tests the NodeWorx SSL Controller.
 *
 * @package    InterWorx
 * @subpackage Tests
 */
class Ctrl_Nodeworx_SslTest extends IWorx_Framework_TestCase {

  const CTRL    = 'Ctrl_Nodeworx_Ssl';
  const SERVICE = 'SSL_Proftpd';

  /**
   * Test.
   */
  public function testIndexAction() {
    $NW     = self::getMasterNodeWorx();
    $Reply  = IW::FC()->routeFromPHP( self::CTRL, 'index', array(), $NW );
    $result = $Reply->getData();

    $this->assertArrayHasKey( 'iw_services', $result );
  }

  /**
   * Test.
   */
  public function testGenerateAction() {
    $input =
      array( 'key_length'             => '2048',
             'countryName'            => 'US',
             'stateOrProvinceName'    => 'Pennsylvania',
             'localityName'           => 'Pittsburgh',
             'organizationName'       => 'InterWorx, LLC',
             'organizationalUnitName' => 'SE',
             'commonName'             => '*.interworx.com',
             'emailAddress'           => 'admin@interworx.com' );

    $NW    = self::getMasterNodeWorx();
    $Reply = IW::FC()->routeFromPHP( self::CTRL,
                                     'generate',
                                     $input,
                                     $NW );

    $result = $Reply->getData();

    $this->assertArrayHasKey( 'iw_private_key', $result );
    $this->assertArrayHasKey( 'iw_csr', $result );
    $this->assertArrayHasKey( 'iw_cert', $result );
  }

  /**
   * Test.
   *
   * @depends testGenerateAction
   */
  public function testEditAction() {
    $NW          = self::getMasterNodeWorx();
    $result      = $this->_getSelfSignedCert();
    $private_key = $result['iw_private_key'];
    $crt         = $result['iw_cert'];

    $input = array( 'service' => 'SSL_Proftpd',
                    'key'     => $private_key,
                    'crt'     => $crt );
    $Reply = IW::FC()->routeFromPHP( self::CTRL, 'edit', $input, $NW );

    $this->assertReplySuccessful( $Reply );
  }

  /**
   * Test.
   *
   * @depends testGenerateAction
   */
  public function testViewAction() {
    $NW     = self::getMasterNodeWorx();
    $input  = array( 'service' => 'SSL_Proftpd' );
    $Reply  = IW::FC()->routeFromPHP( self::CTRL, 'view', $input, $NW );
    $result = $Reply->getData();

    $this->assertArrayHasKey( 'iw_private_key', $result );
    $this->assertArrayHasKey( 'iw_cert', $result );
  }

  /**
   * Test.
   *
   * TODO: Would be nice if we could test this, but I'm afraid of it causing
   *       issues with the test because it has to restart iworx.
   *
   * @depends testGenerateAction
   */
  public function testUpdateallAction() {
    $this->markTestIncomplete( 'todo' );
  }

  /**
   * Gets the self-signed cert data.
   *
   * @return array
   */
  private function _getSelfSignedCert() {
    $input =
      array( 'key_length'             => '2048',
             'countryName'            => 'US',
             'stateOrProvinceName'    => 'Pennsylvania',
             'localityName'           => 'Pittsburgh',
             'organizationName'       => 'InterWorx, LLC',
             'organizationalUnitName' => 'SE',
             'commonName'             => '*.interworx.com',
             'emailAddress'           => 'admin@interworx.com' );

    $NW     = self::getMasterNodeWorx();
    $Reply  = IW::FC()->routeFromPHP( self::CTRL, 'generate', $input, $NW );
    $result = $Reply->getData();

    return $result;
  }
}
