<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Jonathan Daniel <jdaniel@interworx.com>
 * @date    Jun 5, 2009
 */

/**
 * IWorxGemsTest.
 *
 * @package    InterWorx
 * @subpackage Tests
 *
 */
class IWorxGemsTest extends IWorx_Framework_TestCase {

  const GEM_NAME = 'yoda';

  /**
   * Tests the isRailsInstalled function.
   */
  public function testIsRailsInstalled() {
    $is_installed = IWorxGems::isRailsEnabled();
    $this->assertTrue( is_bool( $is_installed ) === true );
  }

  /**
   * Tests the isRailsEnabled function.
   */
  public function testIsRailsEnabled() {
    $is_enabled = IWorxGems::isRailsEnabled();
    $this->assertTrue( is_bool( $is_enabled ) === true );
  }

  /**
   * Tests the gemGemHome function.
   */
  public function testGetGemHome() {
    if( IWorxGems::isRailsEnabled() === false ) {
      return;
    }

    $this->addSWAccountIfNecessary();

    $SiteWorx = new SiteWorx( self::SW_DOMAIN );
    $uname    = $SiteWorx->getUniqname();
    $gem_home = IWorxGems::getGemHome( $uname );

    $this->assertTrue( is_string( $gem_home ) );
  }

  /**
   * Tests the systemGemList function.
   */
  public function testSystemGemListAll() {
    if( IWorxGems::isRailsEnabled() === false ) {
      return;
    }

    $gems     = IWorxGems::systemGemList();
    $all_good = $this->_areGemsGood( $gems );
    $this->assertTrue( $all_good === true );
  }

  /**
   * Tests listing all remote gems.
   */
  public function testRemoteGemListAll() {
    if( IWorxGems::isRailsEnabled() === false ) {
      return;
    }

    $gems     = IWorxGems::remoteGemList();
    $all_good = $this->_areGemsGood( $gems );
    $this->assertTrue( $all_good === true );
  }

  /**
   * Tests getting one remote gem.
   */
  public function testRemoteGemListOne() {
    if( IWorxGems::isRailsEnabled() === false ) {
      return;
    }

    $name = self::GEM_NAME;
    $this->_installGem( $name );
    $gems = IWorxGems::remoteGemList( $name );

    $this->assertTrue( empty( $gems ) === false );
    $this->assertTrue( $gems[0]['name'] == $name );
  }

  /**
   * Test listing local gems.
   */
  public function testLocalGemList() {
    if( IWorxGems::isRailsEnabled() === false ) {
      return;
    }

    $this->addSWAccountIfNecessary();
    $SiteWorx = new SiteWorx( self::SW_DOMAIN );
    $domain   = $SiteWorx->getMasterDomainName();
    $name     = self::GEM_NAME;

    $this->_installGem( $name );

    $gems = IWorxGems::localGemList( $domain, $name );

    $this->assertTrue( empty( $gems ) === false );
    $this->assertTrue( $gems[0]['name'] == $name );
  }

  /**
   * Installs the selected gem.
   *
   * @param string $name
   */
  private function _installGem( $name ) {
    $SiteWorx = new SiteWorx( self::SW_DOMAIN );
    $domain   = $SiteWorx->getMasterDomainName();

    $gems = Ini::get( Ini::IWORX_BIN, 'gems' );
    $cmd  = "$gems --install --gem-name \"$name\" --domain $domain";
    IWorxExec::exec( $cmd, $result, $retval );
  }

  /**
   * Checks to make sure the given games are valid.
   *
   * @param array $gems
   * @return boolean
   */
  private function _areGemsGood( array $gems ) {
    $all_good = true;
    foreach( $gems as $gem ) {
      if( !empty( $gem ) &&
          !empty( $gem['name'] ) &&
          !empty( $gem['latest_version'] ) ) {
        $all_good = $all_good && true;
      } else {
        $all_good = $all_good && false;
      }//end if
    }//end foreach
    return $all_good;
  }
}
