<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Jonathan Daniel <jdaniel@interworx.com>
 * @date    Mar 25, 2010
 */

/**
 * Test for the HTML input.
 *
 * @package    InterWorx
 * @subpackage Tests
 */
class Input_HtmlTest extends PHPUnit_Framework_TestCase {

  /**
   * Good data.
   *
   * @return array
   */
  public function getGoodData() {
    $output   = [];
    $output[] = array( 'Hello' );
    $output[] = array( '<strong>Hello!</strong>' );
    $output[] = array( "Something goes here \n\n" );

    return $output;
  }

  /**
   * Bad data.
   *
   * @return array
   */
  public function getBadData() {
    $output   = [];
    $output[] = array( "<script>alert('hello');</script>" );

    $output[] = array( '<script>document.getElementByName( ' .
                       "'body' ).innerHtml = 'somthingevil';</script>" );

    $output[] = array( '<img src="javascript:alert(\'XSS\');">' );

    $output[] = array( '<IMG SRC=`javascript:alert("RSnake says, \'XSS\'")`>' );

    $output[] = array( '<IMG SRC=&#106;&#97;&#118;&#97;&#115;&#99;' .
                       '&#114;&#105;&#112;&#116;&#58;&#97;&#108;&#101;&#114;&#116;&#40;' .
                       '&#39;&#88;&#83;&#83;&#39;&#41;>' );

    $output[] = array( '<IMG SRC=&#0000106&#0000097&#0000118&#0000097&' .
                       '#0000115&#0000099&#0000114&#0000105&#0000112&#0000116&' .
                       '#0000058&#0000097&#0000108&#0000101&#0000114&#0000116&' .
                       '#0000040&#0000039&#0000088&#0000083&#0000083&#0000039&#0000041>' );

    $output[] = array( '<IMG SRC="jav ascript:alert(\'XSS\');">' );

    $output[] = array( '<STYLE>BODY{-moz-binding:url(' .
                       '"http://ha.ckers.org/xssmoz.xml#xss")}</STYLE>' );

    return $output;
  }

  /**
   * Tests that valid data is not filtered.
   *
   * @param string $data
   *
   * @dataProvider getGoodData()
   */
  public function testValidDataNotFiltered( $data ) {
    $Input = new Input_Html( 'html_test' );

    $Input->setCurrentValue( $data );
    $this->assertEquals( $data, $Input->getCurrentValue() );
  }

  /**
   * Tests that invalid data is properly filtered.
   *
   * @param string $data
   *
   * @dataProvider getBadData()
   */
  public function testInvalidDataIsFiltered( $data ) {
    $Input = new Input_Html( 'html_test' );
    $Input->setCurrentValue( $data );
    $current_value = $Input->getCurrentValue();

    // TODO
    // make the check smarter
    // we're only testing that the bad stuff is removed for now
    $this->assertTrue( empty( $current_value ) );
  }
}
