<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package    InterWorx
 * @subpackage Tests
 * @author     Jon Daniel <jdaniel@interworx.com>
 * @date       Jan 21, 2010
 */

/**
 * Tests for the proftp driver.
 *
 * @package    InterWorx
 * @subpackage Tests
 */
class ProFTPTest extends IWorx_Framework_TestCase {

  /**
   * Test to ensure bug #1383 has been corrected.
   */
  public function testUpdateSQLFile() {
    ProFTP::updateSQLFile( Ini::get( Ini::PROFTPD, 'dsn' ) );

    $ftp_conf = file_get_contents( Ini::get( Ini::PROFTPD_FILE, 'config' ) );
    $pattern  = '^SQLConnectInfo\s+iworx_ftp@(.+)\siworx_ftp\s(.+)^';

    preg_match( $pattern, $ftp_conf, $matches );

    $host = $matches[1];
    $pass = $matches[2];

    $dsn = "mysql://iworx_ftp:{$pass}@{$host}/iworx_ftp";

    $this->assertTrue( $this->_testDsn( $dsn ),
                       "Unable to connect to iworx ftp db using {$dsn}" );
  }

  /**
   * Tests to see if the given dsn is working.
   *
   * @param string $dsn
   * @return boolean
   */
  private function _testDsn( $dsn ) {
    try {
      $db = IWorxDbUtil::db_connect( $dsn );
      return true;
    } catch( IWorx_Exception_DbUtil $e ) {
      return false;
    }
  }
}